@@ -1,4 +1,4 @@
 from .wallbox import WallboxClient
 from . import msg_types
 
-__all__ = ["WallboxClient", "msg_types"]
+__all__ = ["WallboxClient", "msg_types", "exceptions"]
